@@ -7,8 +7,8 @@ from functools import partial
 import click
 
 from cerebra.germline_filter import germline_filter
-from cerebra.count_mutations import count_mutations
-from cerebra.find_aa_mutations import find_aa_mutations
+from cerebra.count_variants import count_variants
+from cerebra.find_peptide_variants import find_peptide_variants
 
 click.option = partial(click.option, show_default=True)
 
@@ -20,15 +20,15 @@ settings = dict(help_option_names=['-h', '--help'])
              context_settings=settings)
 def cli():
     """
-    high-throughput summarizing of vcf entries following a sequencing
-    experiment
+    a tool for fast and accurate summarizing of variant calling
+    format (VCF) files
     """
     pass
 
 
 cli.add_command(germline_filter, name='germline-filter')
-cli.add_command(count_mutations, name='count-mutations')
-cli.add_command(find_aa_mutations, name='find-aa-mutations')
+cli.add_command(count_variants, name='count-variants')
+cli.add_command(find_peptide_variants, name='find-peptide-variants')
 
 if __name__ == "__main__":
     cli()
